==> kubernetes-model-1.0.9-sources.jar: annotations/io/fabric8/openshift/api/model/ParameterFluent.java <==
package io.fabric8.openshift.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class ParameterFluent<T extends ParameterFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     String description;     String from;     String generate;     String name;     String value;     Map<String, Object> additionalProperties = new HashMap();

    public String getDescription(){
    return this.description;
    }
    public T withDescription( String description){
    this.description=description; return (T) this;
    }
    public String getFrom(){
    return this.from;
    }
    public T withFrom( String from){
    this.from=from; return (T) this;
    }
    public String getGenerate(){
    return this.generate;
    }
    public T withGenerate( String generate){
    this.generate=generate; return (T) this;
    }
    public String getName(){
    return this.name;
    }
    public T withName( String name){
    this.name=name; return (T) this;
    }
    public String getValue(){
    return this.value;
    }
    public T withValue( String value){
    this.value=value; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ParameterFluent that = (ParameterFluent) o;
if (description != null ? !description.equals(that.description) :that.description != null) return false;
if (from != null ? !from.equals(that.from) :that.from != null) return false;
if (generate != null ? !generate.equals(that.generate) :that.generate != null) return false;
if (name != null ? !name.equals(that.name) :that.name != null) return false;
if (value != null ? !value.equals(that.value) :that.value != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.14-sources.jar: annotations/io/fabric8/openshift/api/model/ParameterFluent.java <==
package io.fabric8.openshift.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class ParameterFluent<T extends ParameterFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     String description;     String from;     String generate;     String name;     Boolean required;     String value;     Map<String, Object> additionalProperties = new HashMap();

    public String getDescription(){
    return this.description;
    }
    public T withDescription( String description){
    this.description=description; return (T) this;
    }
    public String getFrom(){
    return this.from;
    }
    public T withFrom( String from){
    this.from=from; return (T) this;
    }
    public String getGenerate(){
    return this.generate;
    }
    public T withGenerate( String generate){
    this.generate=generate; return (T) this;
    }
    public String getName(){
    return this.name;
    }
    public T withName( String name){
    this.name=name; return (T) this;
    }
    public Boolean isRequired(){
    return this.required;
    }
    public T withRequired( Boolean required){
    this.required=required; return (T) this;
    }
    public String getValue(){
    return this.value;
    }
    public T withValue( String value){
    this.value=value; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ParameterFluent that = (ParameterFluent) o;
if (description != null ? !description.equals(that.description) :that.description != null) return false;
if (from != null ? !from.equals(that.from) :that.from != null) return false;
if (generate != null ? !generate.equals(that.generate) :that.generate != null) return false;
if (name != null ? !name.equals(that.name) :that.name != null) return false;
if (required != null ? !required.equals(that.required) :that.required != null) return false;
if (value != null ? !value.equals(that.value) :that.value != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
